/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.actions;

import com.opensymphony.xwork2.ActionSupport;
import com.opensymphony.xwork2.ActionContext;
import org.wso2.registry.Registry;
import org.wso2.registry.RegistryException;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.web.ConsoleConstants;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.registry.jdbc.JDBCRegistry;
import org.wso2.usermanager.Realm;
import org.apache.struts2.StrutsStatics;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.ServletContext;

public abstract class AbstractRegistryAction extends ActionSupport {

    protected Registry getRegistry() throws RegistryException {

        ActionContext actionContext = ActionContext.getContext();

        HttpServletRequest request =
                (HttpServletRequest) actionContext.get(StrutsStatics.HTTP_REQUEST);
        Registry registry =
                (Registry) request.getSession().getAttribute(ConsoleConstants.USER_REGISTRY);

        if (registry == null) {

            // user is not logged in. create a annoymous registry for the user.

            ServletContext context =
                    (ServletContext) actionContext.get(StrutsStatics.SERVLET_CONTEXT);
            JDBCRegistry jdbcRegistry =
                    (JDBCRegistry) context.getAttribute(RegistryConstants.REGISTRY);
            Realm realm = (Realm) request.getSession().getServletContext().
                                        getAttribute(RegistryConstants.REGISTRY_REALM);
            SecureRegistry secureRegistry = new SecureRegistry(
                    RegistryConstants.ANONYMOUS_USER, "guest", jdbcRegistry, realm);

            request.getSession().setAttribute(ConsoleConstants.USER_REGISTRY, secureRegistry);

            registry = secureRegistry;
        }

        return registry;
    }

    public boolean isLoggedIn() throws RegistryException {

        Registry registry = getRegistry();
        if (registry instanceof SecureRegistry) {
            SecureRegistry secureRegistry = (SecureRegistry) registry;
            String userID = secureRegistry.getUserID();

            if (!userID.equals(RegistryConstants.ANONYMOUS_USER)) {
                return true;
            }
        }

        return false;
    }

    public String getUserName() throws RegistryException {

        Registry registry = getRegistry();
        if (registry instanceof SecureRegistry) {
            SecureRegistry secureRegistry = (SecureRegistry) registry;
            return secureRegistry.getUserID();
        }

        return null;
    }
}
